#
# spec file for package zeitgeist
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2009 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zeitgeist
Version:        1.0.4
Release:        1.1
Summary:        Zeitgeist Engine
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://gitlab.freedesktop.org/zeitgeist/zeitgeist
Source0:        %{url}/-/archive/v%{version}/%{name}-v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-rdflib
BuildRequires:  python3-xml
BuildRequires:  raptor
BuildRequires:  vala
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(telepathy-glib)
BuildRequires:  pkgconfig(xapian-core)
Requires:       python3-xdg
Requires:       python3-xml

%description
Zeitgeist is a service that logs the users activity. The log can be
queried and managed in various ways over a DBus API.

This is the Zeitgeist backend engine.

%package -n libzeitgeist-2_0-0
Summary:        Client library for interacting with the Zeitgeist daemon
License:        LGPL-2.1-or-later

%description -n libzeitgeist-2_0-0
Libzeitgeist is a client library for interacting with the Zeitgeist
daemon.

This package provides the client library for Zeitgeist.

%package -n typelib-1_0-Zeitgeist-2_0
Summary:        Introspection bindings for Zeitgeist client library
License:        LGPL-2.1-or-later

%description -n typelib-1_0-Zeitgeist-2_0
Libzeitgeist is a client library for interacting with the Zeitgeist
daemon.

This package provides the Introspection bindings for Zeitgeist.

%package devel
Summary:        Development files for Zeitgeist client library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Requires:       libzeitgeist-2_0-0 = %{version}
Requires:       typelib-1_0-Zeitgeist-2_0 = %{version}

%description devel
Libzeitgeist is a client library for interacting with the Zeitgeist
daemon.

This package provides the necessary files for development with Zeitgeist.

%prep
%autosetup -n %{name}-v%{version}

%build
./autogen.sh
%configure \
  --enable-fts
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# We have the NEWS and AUTHORS in package doc
rm -rf %{buildroot}%{_datadir}/%{name}/doc
%fdupes %{buildroot}%{python3_sitelib}

%ldconfig_scriptlets -n libzeitgeist-2_0-0

%files
%doc AUTHORS NEWS
%{_bindir}/zeitgeist*
%{python3_sitelib}/zeitgeist/
%{_mandir}/man?/*%{ext_man}
%{_datadir}/zeitgeist/
%{_datadir}/dbus-1/services/org.gnome.zeitgeist.SimpleIndexer.service
%{_datadir}/dbus-1/services/org.gnome.zeitgeist.Engine.service
%{_userunitdir}/zeitgeist.service
%{_userunitdir}/zeitgeist-fts.service
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/zeitgeist-fts
%{_datadir}/bash-completion/completions/zeitgeist-daemon
%{_sysconfdir}/xdg/autostart/zeitgeist-datahub.desktop

%files -n libzeitgeist-2_0-0
%license COPYING
%{_libdir}/libzeitgeist-2.0.so.*

%files -n typelib-1_0-Zeitgeist-2_0
%{_libdir}/girepository-1.0/Zeitgeist-2.0.typelib

%files devel
%license COPYING.GPL
%{_includedir}/zeitgeist-2.0
%{_libdir}/libzeitgeist-2.0.so
%{_libdir}/pkgconfig/zeitgeist-2.0.pc
%{_datadir}/gir-1.0/Zeitgeist-2.0.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/zeitgeist*

%changelog
* Fri Aug  9 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.4:
  * Fix compile error with new vala
  * Move systemd services to session slice
  * Add PartOf=graphical-session.target to all systemd units
  * Ensure releated data is removed when deleting events
  * Fix search_with_relevancies to call proxy with correct arguments
- update to 1.0.3:
  * Fix compile error with new vala
  * Port to python3 and update tests
  * Drop support for python2
- add new make deps
- switch to new upstream url
* Thu Sep  9 2021 Alexei Podvalsky <avvissu@yandex.by>
- Add 0001-use-genericarray-api-only.patch
* Sun Feb 10 2019 bjorn.lie@gmail.com
- Update to version 1.0.2:
  + Overall:
  - Fix compile errors and warnings with new vala.
  - fts: Correctly implement the org.gnome.zeitgeist.Index DBus
    interface.
  - test-log: Use correct free function for ZeitgeistResultSet.
  - Do not require rapper as it is not used anymore.
  - Make ontology2code work with python3.
  - Properly fallback with the Zeitgeist version.
  - rdflib directly to parse the trig files.
  - Update Ontology2code to ba able to specify the output path.
  + Libzeitgeist: Asynchronous out-parameters are only allowed at
    the end of argument lists. THIS IS AN UNAVOIDABLE VALA API
    BREAK.
* Mon Mar  5 2018 luc14n0@linuxmail.org
- Update to version 1.0.1:
  + Fix placeholder in systemd service template
- Update package descriptions to show more explictly the contents
  of the packages.
- Append GPL-2.0-or-later to the devel subpackage to comply with
  the copyrights.
- Adopt the use of make_build macro rather than raw make command,
  following the best practices.
- Drop zeitgeist-1.0-service.patch: fixed upstream.
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license
* Wed Nov  1 2017 mpluskal@suse.com
- Switch to python3
- Cleanup with spec-cleaner
* Mon May 15 2017 avvissu@yandex.by
- Add zeitgeist-1.0-service.patch: Fix placeholder in systemd
  service template.
* Sun Feb 19 2017 zaitor@opensuse.org
- Update to version 1.0:
  + Drop dependency on gnome-common and intltool.
  + Use GNU gettext only.
  + Fix some valac warnings.
  + Use $PYTHON to check for rdflib.
  + Install zeitgeist-fts to pkglibexecdir rather than libexecdir.
  + Use correct names for D-Bus service files.
  + Add systemd user service for each D-Bus session service.
  + Fix bash auto-completions script.
  + Add --vacuum option to Daemon to perform VACUUM SQLite
    database.
  + Libzeitgeist: Ensure the log mainloop uses the current thread's
    context when waiting.
- Drop intltool BuildRequires: Following upstreams changes.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Jul 13 2015 dimstar@opensuse.org
- Update to version 0.9.16:
  + Overall:
  - Don't hardcode python path.
  - Fix build with vala-0.24+.
  - Require glib 2.35.4 and adjust target-glib accordingly.
  + Libzeitgeist:
  - Add -fPIC to libzeitgeist-internal.la and
    libzeitgeist_datamodel-2.0.la.
  - Log: Need to quit the loop also on error, otherwise we
    leave a stray main loop around.
- Changes from version 0.9.15:
  + Libzeitgeist: Fix converting variants to event lists.
  + Datahub: change some warnings to debugs.
- Drop zeitgeist-bnc876272-event-crash.patch,
  zeitgeist-silence-logspam.patch and
  zeitgeist-0.9.14-whereclause-fix.diff: fixed upstream.
* Wed Feb 11 2015 zaitor@opensuse.org
- Add zeitgeist-silence-logspam.patch: Don't spam the logs with
  warnings that aren't really warnings, use debug instead.
* Tue Feb 10 2015 dev@ibboard.co.uk
- Add zeitgeist-0.9.14-whereclause-fix.diff: fix SQL error caused
  by later versions of Vala (boo#910289).
* Thu Jun 12 2014 mgorse@suse.com
- Add zeitgeist-bnc876272-event-crash.patch: fix possible crash
  with a Google Talk account in empathy (bnc#876272).
* Sat Jun 22 2013 zaitor@opensuse.org
- Update to version 0.9.14:
  + Libzeitgeist: Fix managing and tracking registered Monitors.
* Thu May 30 2013 dimstar@opensuse.org
- Update to version 0.9.13:
  + Engine:
  - Adjust resetting of statement to proper sequence.
  - Add custom memory PRAGMA to improve memory consumption.
  + Libzeitgeist:
  - Add default memory PRAGMA to be used by clients.
  + FTS:
  - Improve FTS memory consumption.
  + Overall:
  - Fix compilation breaks for --enable-datahub
  - -disable-downloads-monitor.
* Sat Apr 13 2013 dimstar@opensuse.org
- Update to version 0.9.12:
  + Libzeitgeist:
  - Fix find_related_uris to only print out the ranking if
    EXPLAIN_QUERIES is enabled.
  - Fixed find_related_uris to take RelevantResultType as an
    argument instead of ResultType.
  - Pass copy of templates to search and search_with_relevancies.
  + Overall: Fixed documentation.
* Wed Apr 10 2013 dimstar@opensuse.org
- Update to version 0.9.11:
  + Libzeitgeist:
  - Fix the log's insert_events_no_reply and
    insert_event_no_reply API to not require an async callback.
  - Pass copy of templates to threads in get_events, find_events,
    find_event_ids and find_related_uris.
  - Pass copy of templates to search and search_with_relevancies.
  - Expose RemoteLog's extensions and datapath properties via Log
    class.
  + Fix documentation title to Zeitgeist Reference Manual
* Sat Apr  6 2013 dimstar@opensuse.org
- Also obsolete zeitgeist-datahub-lang package: zeitgeist-datahub
  has been merged.
* Thu Apr  4 2013 dimstar@opensuse.org
- Update License tag as result of review:
  + Main and src package: LGPL-2.1+ and GPL-2.0+.
  + Library and -devel packages: LGPL-2.1+.
* Wed Mar 20 2013 dimstar@opensuse.org
- Update to version 0.9.10:
  + Libzeitgeist:
  - Add new zg#ApplicationAction subject interpretation.
  - Fix sql explanation bug.
- Don't create a -lang package: there haven't been translations
  since version 0.9.0.1.
- Obsolete an eventually installed zeitgeist-lang package.
- Add pkgconfig(gio-2.0), pkgconfig(gtk+-3.0),
  pkgconfig(json-glib-1.0) and pkgconfig(telepathy-glib)
  BuildRequires: new depdencies for the datahub provider.
- Obsolete separate zeitgeist-datahub package.
* Thu Mar 14 2013 dimstar@opensuse.org
- Update to version 0.9.9:
  + This version introduces libzeitgeist2, a Vala port of the
    previously independent libzeitgeist library.
  + Engine:
  - Fixed insertion of large event sets.
  - Fixed database migration to WebDataObject (from some
    RemoteDataObjects).
  - Events missing required meta-data are now rejected.
  + FTS:
  - Fixed to respect ZEITGEIST_DATA_PATH.
  + Python API:
  - RelevantResultType is now included in "from datamodel
    import *".
- Add pkgconfig(gobject-introspection-1.0) BuildRequires: new
  dependency.
- Pass --enable-fts to configure.
- Create new subpackages libzeitgeist-2_0-0,
  typelib-1_0-Zeitgeist-2_0 and zeitgeist-devel.
* Thu Sep  6 2012 dimstar@opensuse.org
- Update to version 0.9.5:
  + Engine:
  - Needs vala 0.16 to build.
  - Optimization of subject interpretation.
  - Set Pragma setting synchronous to NORMAL.
  - Added a tool which sets up a bus in a fake X server (Xvfb)
    and launches a Zeitgeist instance (without datahub or FTS)
    into it.
  - Events are inserted in sequential order.
  + Autoconf:
  - Don't check for Xapian if FTS++ is disabled.
  - Print "SQL debugging" option.
  - Check for gmodule.
- Drop zeitgeist-gmodule.patch: fixed upstream.
- Drop libtool BuildRequires and call to autoreconf: there are no
  patches left.
- Add vala BuildRequires.
- Add pkgconfig(gmodule-2.0) BuildRequires: new checked dependency.
* Mon Jun 11 2012 dimstar@opensuse.org
- Update to version 0.9.0.1:
  + Engine:
  - Fixed FindRelatedEvents.
  - Added support for upgrading from schema version 3.
  + FTS:
  - Fixed double string unescaping (lp#954171).
  - Fixed segmentation fault caused by bug in URI handling.
  - Make sure Xapian is closed before releasing the bus name.
- Changes from version 0.9.0:
  + Engine:
  - Updated the list of recognized MIME-types.
  - Set a size limit (4MiB) on the results returned by individual
    FindEvents and GetEvents calls. Too big queries will result
    in an exception.
  - Improved handling of FTS not being present (Beta 1 would leak
    memory).
  - Enhanced database corruption detection and recovery.
  - DataSourceRegistry: don't ignore bus addresses that
    registered more than one data-source if one of them is
    disabled.
  + FTS:
  - Added a build-time option to disable FTS.
  - The index is now automatically re-build if it gets corrupted.
  - The index is now automatically re-build if the Zeitgeist DB
    is re-created.
  - Split the reindex query into several smaller ones, for
    enhanced performance.
  - Quit when Zeitgeist leaves the bus.
  - Ignore events from Ubuntu One.
  + Python API:
  - Updated the list of recognized MIME-types.
- Rework BuildRequires:
  + Dropped: dbus-1, fdupes,
  + Added: libxapian-devel, pkgconfig(dbus-1),
    pkgconfig(gio-unix-2.0), pkgconfig(glib-2.0),
    pkgconfig(gobject-2.0), pkgconfig(sqlite3)
- There are currently no translations, so we have an empty -lang
  package for now.
- Add zeitgeist-gmodule.patch: link against libgmodule.
- Add libtool BuildRequires and call to autoreconf, as the patch
  above touches the build system.
- No longer build package noarch
* Thu Sep 22 2011 vuntz@opensuse.org
- Update to version 0.8.2:
  + Engine:
  - Storage Monitor: Add support for Network Manager 0.9.
  - The text field in subject templates is now allowed to end
    with an asterisk (*) character (which is treated as plain
    text).
  - Correctly handle current_uri in subject templates from old
    clients (instead of forcing it to the same value as the
    subject's uri).
  - Substantially increase the amount of events that can be
    deleted in a single DeleteEvents call.
  + Python API:
  - Correctly specify the D-Bus interface when using
    introspection.
  - Fix possible exception when the available method list hasn't
    been loaded.
  - The Event constructor now supports creating independent
    copies of events.
* Sun Jul 24 2011 vuntz@opensuse.org
- Update to version 0.8.1.1:
  + Engine:
  - Load extensions after the internal database lookup/cache
    tables have been initialized.
  - Fix problem when replacing an existing Zeitgeist instance
    (lp#809569).
  - Fix possible crash when zeitgeist-datahub isn't available
    (lp#791392).
  + Python API:
  - Fix regression that broke properties (get_version and
    get_extensions).
- Drop zeitgeist-properties-regression.patch: fixed upstream.
* Wed Jul 20 2011 dimstar@opensuse.org
- Add zeitgeist-properties-regression.patch: Fix regression that
  broke properties (get_version and get_extensions). Patch taken
  from launchpad, commit rev 1789.
* Thu Jul  7 2011 vuntz@opensuse.org
- Update to version 0.8.1:
  + Engine:
  - Added a GetDataSourceFromId D-Bus method to the data-source
    registry extension (lp#691690).
  - A backup of the database is created before attempting schema
    upgrades. If something goes wrong, the backup is automatically
    restored (lp#660307).
  - Fixed the "extensions" D-Bus property when it's an empty list
    (lp#787691).
  - Add PID to the output being logged in ~/.cache/ (lp#806030).
  - Ensure the engine doesn't attempt to close twice in a row
    (lp#793714).
  - Minor memory usage improvements.
  + Python API:
  - Changed _DBusInterface to update introspected data after
    reconnections.
  - Added support for registering custom Event and Subject
    subclasses with ZeitgeistClient (lp#799199).
  - Fixed reconnection after a Zeitgeist restart so that the
    method call triggering the reconnection also works -and not
    only later calls- (lp#736176).
  - Added signal reconnection on engine restart for extensions
    (lp#806967).
  - Added an "iteritems()" method to all enumerations
    (RelevantResultType, StorageState and ResultType).
  - Added a "from_timestamp(timestamp)" method to TimeRange.
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Thu Jun  9 2011 vuntz@opensuse.org
- Remove unneeded dependencies:
  + python-gnome Requires: there's no use of gconf anymore.
  + python-rdflib Requires: this is only need at build time.
  + python-gtk Recmomends: the recent files data source is in
    zeitgeist-datahub now.
* Wed May 18 2011 dimstar@opensuse.org
- Update to version 0.8.0:
  + Engine:
  - lp#772041: Fixed secondary sorting by timestamp for most
    ResultTypes
  - Enabled filtering by availability in FindEvents.
  - lp#425258: Added an origin property to events, matching that
    for subjects
  - Added a current_uri property to subjects, which unlike all
    other properties is mutable.
  - Add new sorting types for origin and current_uri.
  - lp#602211: Added support for "move" events, which
    automatically update the current_uri property where
    appropriate
  - lp#598666: Fixed inconsistencies caused by the internal cache
    not being updated when events were deleted
  - lp#489194: Added a Storage Monitor extension which tracks
    network connectivity and removable devices
  - lp#739780: Fixed datahub launching to avoid zombie processes
  - lp#612344: Replaced the Blacklist extension giving it a more
    capable API
  - lp#744818: Do not print a traceback when Zeitgeist fails to
    start because another instance is already running
  - Simplified log output format when printing to stderr.
  + Python API:
  - lp#771970: Fix bug in the connection recovery code
  - Added new ResultTypes:
    {Most,Least}{Recent,Popular}{CurrentUri,EventOrigin}.
  - Created *SubjectOrigin alias for all
    {Most,Least}{Recent,Popular}Origin ResultTypes.
  - Minor documentation improvements.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to 0.7.1:
  + Overall:
  - Added new event interpretation types: AcceptEvent, DenyEvent
    and ExpireEvent.
  - Include NCO in the generated ontologies.
  - Better ./configure check for python-rdflib.
  - Update the manpage to document exit codes.
  + Engine:
  - Expose property information in the D-Bus introspection output
  - Mention column names explicitly when inserting events, for
    compatibility with the upcoming 0.8 release.
  + Python API:
  - Expose DataSourceRegistry's enabled status in a callback.
  - Automatically reconnect to Zeitgeist if the connection is
    lost when using methods asynchronously.
  - lp#673008, lp#727226: Reinstall all active monitors upon
    reconnection.
  - lp#732015: Fix a (harmless) race condition requesting the bus
    name.
- Drop zeitgeist-no-rdfpipe.patch: fixed upstream.
- Escape %% in comments in the .spec file to fix some rpmlint
  warnings.
- Use source services: download_url, recompress and set_version.
* Thu Mar  3 2011 vuntz@opensuse.org
- Remove checks for openSUSE 11.1 or earlier: those versions are
  not maintained anymore.
* Tue Jan 18 2011 federico@novell.com
- Update to version 0.7:
  + Overall:
  - Using logging output for debugging purposes (lp#660440)
  - Stop building man page for zeitgeist-datahub (lp#680360)
  - Allow easy building for KDE (lp#683280)
  - Logging output now displays how many events were actually
    inserted from the batch of requested inserts (lp#660440)
  - Changed License to LGPL 2.1+
  + Engine:
  - Added some new mimetype mappings
  - Speed up the GetEvents method by caching events (lp#686732)
  - Allow extension without public method (lp#691660)
  - Added a read-only DBus property "extensions" to
    org.gnome.zeitgeist.Log (lp#693861)
  - Added helper function to get an extension's name
  - Fixed bug in RemoteInterface.Quit(): make sure to close
    connection to the used bus if this method gets called, this
    is needed if RemoteInterface does not know anything about the
    loop it is running in.
  - Fix sending payload from engine to client (lp#692645)
  - Improve performance of DataSourceRegistry (lp#695311)
  - Improve performance of find_event queries with timerange
    other than TimeRange.always() (lp#672965)
  - Add an auto-filter for broken database entries (lp#598666
    workaround)
  - Introduce new DB schema (version 3) that bundles a few
    performance related fixes (lp#673452, lp#673394)
  + Python API:
  - Fix find_event_for_template to stop ignoring the template
    (lp#690377)
  - Add get_extensions method to ZeitgeistClient
- Add zeitgeist-no-rdfpipe.patch: this removes a check in
  configure, that is not needed anymore.
- Update license tag to LGPLv2.1+.
* Mon Nov 15 2010 dimstar@opensuse.org
- Update to version 0.6:
  + Engine:
  - Added 'zeitgeist-integrity-checker.py' tool to check the
    integrity of an activity log.
  - Optimization of ZeitgeistEngine.find_related_uris() by using
    a different algorithm.
  - lp#643303, lp#665607: Improved database updates
  - lp#650930: If FindEvents-queries are run over the complete
    TimeRange intervall don't add timestamp conditions to the SQL
    statement
  - lp#641198: Improved speed of prefix-search queries by always
    using the index
  + Python API:
  - lp#655164: Added a bunch of new result types
  + Daemon:
  - lp#660415: Code-Improvements to zeitgeist-daemon
  - Fixed '--log-level' option of zeitgeist-daemon, library code
    does not set the log level anymore, the application using the
    python library has to take care of it.
  + Overall:
  - lp#630593: 'zeitgeist-datahub' is not part of the zeitgeist
    project anymore
  - Updates to the test suite.
  - lp#660423: Added `make run` target to the rootlevel Makefile
  + Updated translations.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 0.5.2:
  + Engine:
  - Extensions and the database connection are now shutdown
    gracefully when the Zeitgeist daemon is asked to stop over
    D-Bus.
  - Receiving a SIGHUP indicates a request for a clean shutdown;
    this can be used to signal a system-wide restart request
    after an update.
  - Fixed a bug in TableLookup because of which the internal
    cache wasn't being used.
  - Added a new option, activated by the
    ZEITGEIST_DEBUG_QUERY_PLANS, which prints detailed
    information about each query being executed.
  - Removed superfluous database commits; now they are called
    after all InsertEvent actions have been completed, not once
    for every event.
  - Speed up the initial query retrieving the last event ID by
    fixing it to make use of the database's indexes.
  - Catch any exceptions trying to notify a monitor of changes
    and redirect them to the error log.
  - Fixed LeastRecentActor sorting not working in combination
    with event template filtering (lp#641968).
  - Renamed the LeastRecentActor sorting type to OldestActor and
    implemented a new LeastRecentActor which does what it was
    supposed to do (lp#646124).
  + Datahub:
  - Added a workaround so that events concerning OpenOffice.org
    are logged correctly (lp#646724).
  + Overall:
  - Fix an error in the ontology; it's "rdf:Property", not
    "rdfs:Property".
  - Improved documentation; particularly, the ontology is now
    presented in a separate section with a more readable format.
  - Translation updates.
* Fri Sep 10 2010 dimstar@opensuse.org
- Update to version 0.5.1:
  + Engine:
  - lp#592599: FindEvent*: Event subjects are now joined by a
    logical AND instead of OR
  - Extensions found in the extensions directory are now
    automatically loaded.
  - Install a .pc file so out of tree extensions can figure out
    the install path.
  - Load extensions found in ~/.local/share/zeitgeist/extensions.
  - lp#523761: Let the GtkRecentlyUsed data-source ignore any
    exceptions while trying to parse .desktop files
  - Fix return value of the SetDataSourceEnabled D-Bus method.
  - lp#592599, lp#604747: Extensions: Hooks have been renamed and
    most of them now have pre and post variants
  - Add new ResultTypes for sorting by subject origin
  - Change the hooks API for the Extension class to use pre_* and
    post* hooks to make it clearer when they are run. This change
    also brings in a few new hooks.
  + Python API:
  - ZeitgeistDBusInterface.get_extension is no longer a
    classmethod (in fact, it never really was).
  - ZeitgeistDBusInterface.get_extension now has a third optional
    parameter to change the bus name.
  + Overall:
  - lp#595577: Build system fixes
  + Updated translations.
- Drop zeitgeist-rdflib-3.patch: fixed upstream.
- Use _smp_mflags.
* Sun Aug 29 2010 vuntz@opensuse.org
- Add zeitgeist-rdflib-3.patch: fix build with rdflib 3.0.
* Tue Aug 10 2010 dimstar@opensuse.org
- Update to version 0.5.0:
  + Engine:
  - lp#592599: FindEvent*: Event subjects are now joined by a
    logical AND instead of OR.
  - Extensions found in the extensions directory are now
    automatically loaded.
  - Install a .pc file so out of tree extensions can figure out
    the install path.
  - Load extensions found in ~/.local/share/zeitgeist/extensions.
  - lp#523761: Let the GtkRecentlyUsed data-source ignore any
    exceptions while trying to parse .desktop files.
  - Fix return value of the SetDataSourceEnabled D-Bus method.
  - lp#592599, lp#604747: Extensions: Hooks have been renamed and
    most of them now have pre and post variants.
  - Add new ResultTypes for sorting by subject origin
  - Change the hooks API for the Extension class to use pre_* and
    post* hooks to make it clearer when they are run. This change
    also brings in a few new hooks.
  + Python API:
  - ZeitgeistDBusInterface.get_extension is no longer a
    classmethod (in fact, it never really was).
  - ZeitgeistDBusInterface.get_extension now has a third optional
    parameter to change the bus name.
  + Overall:
  - lp#595577: Build system fixes.
  - Manpage updates.
  + Updated translations.
- The .pc file is kept in the main package, as a split for this
  file alone does not make sense and it does not drag in any other
  - devel packages.
* Wed Jul  7 2010 dimstar@opensuse.org
- Update to version 0.4.0:
  + Engine:
  - Compile the shared-desktop-ontolgies (aka Nepomuk (aka
    OSCAF)) into Python code at build time, and use them for out
    subject classification system
  - You can now negate the fields uri, interpretation,
    manifestation, origin, and mimetype, in event templates by
    prepending the field value with an exclamation mark '!'.
  - You can truncate (aka wildcard) the subject fields uri,
    origin, and mimetype in event templates by appending an
    asterisk '*' to the string.
  - Event templates now match on all child types of the specified
    interpretations and manifestations. Ie. Interpretation.IMAGE
    also matches RASTER_IMAGE and VECTOR_IMAGE.
  - The core database schema is now versioned, meaning that we
    can migrate data if the DB ever needs to change in layout. It
    also brings slightly faster startup of the daemon when we
    detect that the schema version is what we expect
  - Two new environment variables ZEITGEIST_DEFAULT_EXTENSIONS
    and ZEITGEIST_EXTRA_EXTENSIONS controlling which extensions
    are loaded
  - Man pages updated with --no-datahub and environment variables
    to control the data paths and loaded extensions
  - Auto upgrades of schemas
  - Some Nepomuk type URIs where wrong and will be fixed
    automatically in the schema upgrade of the DB
  - Fix DeleteEvents to work with arbitrarily huge amounts of
    IDs.
  - Set event.id before passing events to the extension hooks so
    extensions can make use of the event ids
  + Python API:
  - TimeRange sprouted a few new useful methods.
  + Ontology:
  - Removed {Interpretation,Manifestation}.UNKNOWN. If you really
    really (like really!) can not come up with a good
    interpretation or manifestation don't log it - or insert an
    empty string instead.
  - What was subject's Manifestation.WEB_HISTORY is now
    represented by a combination of Interpretation.WEBSITE and
    Manifestation.REMOTE_DATA_OBJECT.
  - Manifestation.FILE has been renamed to
    Manifestation.FILE_DATA_OBJECT.
  - Event interpretations OPEN_EVENT and VISIT_EVENT has been
    coalesced into a new interpretation type called ACCESS_EVENT.
  - Event interpretation SAVE_EVENT has been coalesced into
    MODIFY_EVENT.
  - The following interpretations has been removed because we
    need a suitable alternative defined in the Nepomuk/OSCAF
    scope: BROADCAST_MESSAGE, FEED_MESSAGE, SYSTEM_RESOURCE,
    NOTE.
  - Interpretation.MUSIC is now Interpretation.AUDIO.
  - The following event interpretations has been removed because
    they had unclear meanings or limited general usefulness:
    FOCUS_EVENT, WARN_EVENT, ERROR_EVENT.
  + Overall:
  - Other fixes and code enhancements.
  - Manpage updates.
  + Updated translations.
- Add raptor, python-xml and python-rdflib BuildRequires.
- Add python-rdflib Requires.
* Fri Jun  4 2010 vuntz@opensuse.org
- Use a valid RPM group: Productivity/Other. Note that it's not a
  file manager, so Productivity/File utilities is not appropriate.
* Mon May 10 2010 dimstar@opensuse.org
- Update to version 0.3.3.1:
  + Engine:
  - Added a LastSeen property to data-sources.
  - Fixed a bug in the DataSourceRegistry extension where it
    failed to handle the disconnection signal from data-sources
    with several running instances.
  + Overall:
  - This fixes a bug where zeitgeist-datahub would fail to start.
- Changes from version 0.3.3:
  + Engine:
  - lp#493903: Added MostPopularActor, LeastPopularActor,
    MostRecentActor and LeastRecentActor as possible ReturnTypes
    for FindEvents and FindEventsId
  - Let {Find,Get,Insert}* hooks know the bus name of the caller,
    when executed over D-Bus.
  - Add an extension implementing a data-source registry
    (allowing to disable data-sources from a centralized place
    and see their description).
  - Overhauled FindRelatedUris for better results and improved
    performance.
  - lp#490242: Changed FindEvents, FindEventIds and
    FindRelatedUris to not treat zeros in the given TimeRange
    specially; "(0, 0)" can no longer be used
  - lp#526357: Fixed a crash in the GtkRecentlyUsed data-source
    parsing malfored .desktop files (LP: #526357)
  - lp#510761: Added support for more file mimetypes
  - lp#523761: Fixed a crash in the GtkRecentlyUsed data-source
    trying to read broken symlinks disguised as .desktop files
  - lp#531793: Fixed a crash in the GtkRecentlyUsed data-source
    which happened when there was no display friendly version of
    a URI
  - Renamed --no-passive-loggers option to --no-datahub. Output
    printed by zeitgeist-datahub is no longer visible in
    zeitgeist-daemon's output.
  - Added --log-level option to change the output verbosity.
  - lp#491646: DeleteEvents now correctly removes any
    unreferenced values (URIs, actors, etc.) and not only the
    events themselves
  - lp#557708: Fixed insertion of events with a payload
  - Fixed an exception in DeleteEvents.
  - lp#566184: Fixed event deletions not always getting committed
  - Ignore deletion requests for non-existant events.
  + Python API:
  - Made the Interpretation and Manifestation classes iterable.
  - Added symbol lookup by URI, in the form of dictionary access.
  - Fixed the display name for Interpretation.SOURCECODE.
  - lp#510804: Fixed find_events_for_values and
    find_event_ids_for_values
  - Added a get_extension() method to ZeitgeistDBusInterface, to
    get convenient access to D-Bus interfaces provided by engine
    extensions.
  + Overall:
  - More fixes and code enhancements.
  - Manpage updates.
  - Translation updates.
* Wed Jan 20 2010 awafaa@opensuse.org
- Update to version 0.3.2:
  + Added FindEvents, optimized shorthand for
    GetEvents(FindEventIds(…)).
  + Fixed DeleteEvents and make it ignore bad requests.
  + Fixed GetEvents not to raise an exception when called with an
    empty list.
  + ZeitgeistClient.get_version() now returns a Python list.
  + Some code refactoring, documentation changes and other little
    fixes.
* Fri Jan 15 2010 vuntz@opensuse.org
- Update to version 0.3.1:
  + Add a FindRelatedUris() method to the core DBus API (also to
    the Python client lib). This can be used to find URIs that
    occur in relation to a set of events, sorted by relevancy.
  + The Zeitgeist engine now exposes a Blacklist API over DBus
    which can be used to block events from entering the log
  + The engine now also exposes a fine grained monitoring system
    that can be used to listen for updates to the log
  + InsertEvents() now return an event id of 0 for events that are
    blocked or otherwise fail insertion
  + Extensions can now provide hooks to block or change events
    before they are inserted into the log
  + Remove support for more than one backend. What was known as the
    "Resonance backend" is now just "the engine"
  + Removed method from DBus API GetLastTimestampForActor
  + Lots more unit tests added
  + The engine will now load a default set of extensions on startup
  + Overhaul and restructure our Sphinx-based API-documentation
    system.
  + API documentation is more or less at 100%% both for the DBus API
    and the Python client library
  + Bash completion for zeitgeist-daemon
  + Code style cleanups
  + Bugfix: You may now request more than 999 events in one go from
    GetEvents()
  + Bugfix: In find_eventids where using more than one event
    template resulted in all but the first one ignoring the
    timestamp restriction
  + Bugfix: Fix URL of Interpretation.APPLICATION to correct
    Nepomuk URI
  + More bugfixes
- Changes from version 0.3.0:
  + Disclaimers:
  - Support querying only for available items (eg. filtering out
    deleted files, not listing files on detached USB storage,
    etc.) is exposed in the API but doesn't work yet.
  - The database layout may change again before 0.4.0.
  - The event ontologies are not yet set in stone, and minor
    changes are expected
  - Only one logger is enabled for now: the one monitoring recent
    files. In coming releases this logger may well be deprecated
    in favour of application specific plugins.
  + Complete rework of engine and DBus API.
  + Public Python client API defined in zeitgeist.datamodel and
    zeitgeist.client modules
  + Documented public API with Sphinx
  + Changed Ontology from XESAM to Nepomuk.
  + Removed the Storm backend (obsoleted in 0.2.1).
  + Removed the Querymancer backend.
  + Support for event payloads (binary attachments to events)
  + An extension API for the core engine, allowing extensions
    direct access to the DB
- Change python-devel BuildRequires to python.
- Change python-gtk Requires to a Recommends.
* Tue Aug 18 2009 vuntz@novell.com
- Add python-gnome and python-gtk Requires.
* Mon Aug 17 2009 dominique-obs@leuenberger.net
- Updated to version 0.2.1
  + Fully backwards compatible.
  + Added compatibility with Python version 2.5.
  + Removed the Storm dependency, obtaining general performance
    improvements.
  + Removed the need for a patched PyGTK.
  + Made the GtkRecentlyUser logger more robust (fixes an infinit
    loop on some systems).
  + Improved performance of DeleteItems and UpdateItems.
  + Fixed a problem with the contents of the EventsChanged signal.
  + Fixed InsertEvents to enforce "mimetype" as a required value.
  + Fixed a bug where the sorting_asc=True in FindEvents would be
    ignored if used together with mode="mostused" (lp#404947).
  + Highly improved caching.
  + Added a "--quit" option to zeitgeist-daemon to stop any running
    daemon.
  + General code improvements, new test cases and other minor fixes
- Remove runtime dependency on python-storm.
* Mon Aug  3 2009 dominique-obs@leuenberger.net
- package up zeitgeist 0.2 for openSUSE
